SWDEV-244772 - Fix dtest hipMemcpyWithStreamMultiThread.cpp.

hipSetDevice is not used correctly to allocate on multiple devices in mGPU setup.
Due to which hipMalloc was called on the same device on multiple threads leading to out of memory issues on some devices with lesser memory.

Change-Id: I0e5b1bc028b9ecb11bd40c3a5edf715f8bd721ff


[ROCm/clr commit: 6f5e63ebac]
Этот коммит содержится в:
Satyanvesh Dittakavi
2020-07-21 09:49:31 -04:00
родитель 2bf550d3c1
Коммит 89d36cba5f
+2
Просмотреть файл
@@ -467,6 +467,7 @@ void HipMemcpyWithStreamMultiThreadtests::TestkindDefaultForDtoD(void) {
&A_h[0], &B_h[0], &C_h[0], N, false);
for (int i=1; i < numDevices; ++i) {
HIPCHECK(hipSetDevice(i));
HIPCHECK(hipMalloc(&A_d[i], Nbytes));
HIPCHECK(hipMalloc(&B_d[i], Nbytes));
HIPCHECK(hipMalloc(&C_d[i], Nbytes));
@@ -476,6 +477,7 @@ void HipMemcpyWithStreamMultiThreadtests::TestkindDefaultForDtoD(void) {
hipStream_t stream[numDevices];
for (int i=0; i < numDevices; ++i) {
HIPCHECK(hipSetDevice(i));
HIPCHECK(hipStreamCreate(&stream[i]));
}